Struct partiql_eval::eval::EvalPlan
source · pub struct EvalPlan { /* private fields */ }Expand description
Represents a PartiQL evaluation query plan which is a plan that can be evaluated to produce
a result. The plan uses a directed petgraph::StableGraph.
Implementations
sourceimpl EvalPlan
impl EvalPlan
sourcepub fn new(
mode: EvaluationMode,
plan_graph: StableGraph<Box<dyn Evaluable>, u8, Directed>
) -> Self
pub fn new( mode: EvaluationMode, plan_graph: StableGraph<Box<dyn Evaluable>, u8, Directed> ) -> Self
Creates a new evaluation plan.
sourcepub fn execute_mut<'c>(
&mut self,
ctx: &'c dyn EvalContext<'c>
) -> Result<Evaluated, EvalErr>
pub fn execute_mut<'c>( &mut self, ctx: &'c dyn EvalContext<'c> ) -> Result<Evaluated, EvalErr>
Executes the plan while mutating its state by changing the inputs and outputs of plan operators.
pub fn to_dot_graph(&self) -> String